@@ -1,87 +1,69 @@
 /*
-    Copyright (c) 2007-2016 Contributors as noted in the AUTHORS file
+    Copyright (c) 2007-2014 Contributors as noted in the AUTHORS file
 
-    This file is part of libzmq, the ZeroMQ core engine in C++.
+    This file is part of 0MQ.
 
-    libzmq is free software; you can redistribute it and/or modify it under
-    the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 3 of the License, or
+    0MQ is free software; you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License as published by
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
-    As a special exception, the Contributors give you permission to link
-    this library with independent modules to produce an executable,
-    regardless of the license terms of these independent modules, and to
-    copy and distribute the resulting executable under terms of your choice,
-    provided that you also meet, for each linked independent module, the
-    terms and conditions of the license of that module. An independent
-    module is a module which is not derived from or based on this library.
-    If you modify this library, you must extend this exception to your
-    version of the library.
-
-    libzmq is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
-    License for more details.
+    0MQ is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU Lesser General Public License for more details.
 
     You should have received a copy of the GNU Lesser General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "precompiled.hpp"
 #include <new>
 #include <stddef.h>
 
-#include "macros.hpp"
 #include "pipe.hpp"
 #include "err.hpp"
 
 #include "ypipe.hpp"
 #include "ypipe_conflate.hpp"
 
-int zmq::pipepair (class object_t *parents_[2],
-                   class pipe_t *pipes_[2],
-                   int hwms_[2],
-                   bool conflate_[2])
+int zmq::pipepair (class object_t *parents_ [2], class pipe_t* pipes_ [2],
+    int hwms_ [2], bool conflate_ [2])
 {
     //   Creates two pipe objects. These objects are connected by two ypipes,
     //   each to pass messages in one direction.
 
-    typedef ypipe_t<msg_t, message_pipe_granularity> upipe_normal_t;
-    typedef ypipe_conflate_t<msg_t> upipe_conflate_t;
+    typedef ypipe_t <msg_t, message_pipe_granularity> upipe_normal_t;
+    typedef ypipe_conflate_t <msg_t> upipe_conflate_t;
 
     pipe_t::upipe_t *upipe1;
-    if (conflate_[0])
+    if(conflate_ [0])
         upipe1 = new (std::nothrow) upipe_conflate_t ();
     else
         upipe1 = new (std::nothrow) upipe_normal_t ();
     alloc_assert (upipe1);
 
     pipe_t::upipe_t *upipe2;
-    if (conflate_[1])
+    if(conflate_ [1])
         upipe2 = new (std::nothrow) upipe_conflate_t ();
     else
         upipe2 = new (std::nothrow) upipe_normal_t ();
     alloc_assert (upipe2);
 
-    pipes_[0] = new (std::nothrow)
-      pipe_t (parents_[0], upipe1, upipe2, hwms_[1], hwms_[0], conflate_[0]);
-    alloc_assert (pipes_[0]);
-    pipes_[1] = new (std::nothrow)
-      pipe_t (parents_[1], upipe2, upipe1, hwms_[0], hwms_[1], conflate_[1]);
-    alloc_assert (pipes_[1]);
+    pipes_ [0] = new (std::nothrow) pipe_t (parents_ [0], upipe1, upipe2,
+        hwms_ [1], hwms_ [0], conflate_ [0]);
+    alloc_assert (pipes_ [0]);
+    pipes_ [1] = new (std::nothrow) pipe_t (parents_ [1], upipe2, upipe1,
+        hwms_ [0], hwms_ [1], conflate_ [1]);
+    alloc_assert (pipes_ [1]);
 
-    pipes_[0]->set_peer (pipes_[1]);
-    pipes_[1]->set_peer (pipes_[0]);
+    pipes_ [0]->set_peer (pipes_ [1]);
+    pipes_ [1]->set_peer (pipes_ [0]);
 
     return 0;
 }
 
-zmq::pipe_t::pipe_t (object_t *parent_,
-                     upipe_t *inpipe_,
-                     upipe_t *outpipe_,
-                     int inhwm_,
-                     int outhwm_,
-                     bool conflate_) :
+zmq::pipe_t::pipe_t (object_t *parent_, upipe_t *inpipe_, upipe_t *outpipe_,
+      int inhwm_, int outhwm_, bool conflate_) :
     object_t (parent_),
     inpipe (inpipe_),
     outpipe (outpipe_),
@@ -89,8 +71,6 @@ zmq::pipe_t::pipe_t (object_t *parent_,
     out_active (true),
     hwm (outhwm_),
     lwm (compute_lwm (inhwm_)),
-    inhwmboost (-1),
-    outhwmboost (-1),
     msgs_read (0),
     msgs_written (0),
     peers_msgs_read (0),
@@ -98,7 +78,6 @@ zmq::pipe_t::pipe_t (object_t *parent_,
     sink (NULL),
     state (active),
     delay (true),
-    server_socket_routing_id (0),
     conflate (conflate_)
 {
 }
@@ -121,29 +100,17 @@ void zmq::pipe_t::set_event_sink (i_pipe_events *sink_)
     sink = sink_;
 }
 
-void zmq::pipe_t::set_server_socket_routing_id (
-  uint32_t server_socket_routing_id_)
+void zmq::pipe_t::set_identity (const blob_t &identity_)
 {
-    server_socket_routing_id = server_socket_routing_id_;
+    identity = identity_;
 }
 
-uint32_t zmq::pipe_t::get_server_socket_routing_id ()
+zmq::blob_t zmq::pipe_t::get_identity ()
 {
-    return server_socket_routing_id;
+    return identity;
 }
 
-void zmq::pipe_t::set_router_socket_routing_id (
-  const blob_t &router_socket_routing_id_)
-{
-    router_socket_routing_id.set_deep_copy (router_socket_routing_id_);
-}
-
-const zmq::blob_t &zmq::pipe_t::get_routing_id ()
-{
-    return router_socket_routing_id;
-}
-
-const zmq::blob_t &zmq::pipe_t::get_credential () const
+zmq::blob_t zmq::pipe_t::get_credential () const
 {
     return credential;
 }
@@ -189,9 +156,8 @@ read_message:
 
     //  If this is a credential, save a copy and receive next message.
     if (unlikely (msg_->is_credential ())) {
-        const unsigned char *data =
-          static_cast<const unsigned char *> (msg_->data ());
-        credential.set (data, msg_->size ());
+        const unsigned char *data = static_cast <const unsigned char *> (msg_->data ());
+        credential = blob_t (data, msg_->size ());
         const int rc = msg_->close ();
         zmq_assert (rc == 0);
         goto read_message;
@@ -203,7 +169,7 @@ read_message:
         return false;
     }
 
-    if (!(msg_->flags () & msg_t::more) && !msg_->is_routing_id ())
+    if (!(msg_->flags () & msg_t::more) && !msg_->is_identity ())
         msgs_read++;
 
     if (lwm > 0 && msgs_read % lwm == 0)
@@ -217,7 +183,7 @@ bool zmq::pipe_t::check_write ()
     if (unlikely (!out_active || state != active))
         return false;
 
-    bool full = !check_hwm ();
+    bool full = hwm > 0 && msgs_written - peers_msgs_read == uint64_t (hwm);
 
     if (unlikely (full)) {
         out_active = false;
@@ -233,9 +199,9 @@ bool zmq::pipe_t::write (msg_t *msg_)
         return false;
 
     bool more = msg_->flags () & msg_t::more ? true : false;
-    const bool is_routing_id = msg_->is_routing_id ();
+    const bool is_identity = msg_->is_identity ();
     outpipe->write (*msg_, more);
-    if (!more && !is_routing_id)
+    if (!more && !is_identity)
         msgs_written++;
 
     return true;
@@ -274,7 +240,7 @@ void zmq::pipe_t::process_activate_read ()
 
 void zmq::pipe_t::process_activate_write (uint64_t msgs_read_)
 {
-    //  Remember the peer's message sequence number.
+    //  Remember the peers's message sequence number.
     peers_msgs_read = msgs_read_;
 
     if (!out_active && state == active) {
@@ -291,16 +257,16 @@ void zmq::pipe_t::process_hiccup (void *pipe_)
     outpipe->flush ();
     msg_t msg;
     while (outpipe->read (&msg)) {
-        if (!(msg.flags () & msg_t::more))
+       if (!(msg.flags () & msg_t::more))
             msgs_written--;
-        int rc = msg.close ();
-        errno_assert (rc == 0);
+       int rc = msg.close ();
+       errno_assert (rc == 0);
     }
-    LIBZMQ_DELETE (outpipe);
+    delete outpipe;
 
     //  Plug in the new outpipe.
     zmq_assert (pipe_);
-    outpipe = (upipe_t *) pipe_;
+    outpipe = (upipe_t*) pipe_;
     out_active = true;
 
     //  If appropriate, notify the user about the hiccup.
@@ -310,8 +276,9 @@ void zmq::pipe_t::process_hiccup (void *pipe_)
 
 void zmq::pipe_t::process_pipe_term ()
 {
-    zmq_assert (state == active || state == delimiter_received
-                || state == term_req_sent1);
+    zmq_assert (state == active
+            ||  state == delimiter_received
+            ||  state == term_req_sent1);
 
     //  This is the simple case of peer-induced termination. If there are no
     //  more pending messages to read, or if the pipe was configured to drop
@@ -330,7 +297,8 @@ void zmq::pipe_t::process_pipe_term ()
 
     //  Delimiter happened to arrive before the term command. Now we have the
     //  term command as well, so we can move straight to term_ack_sent state.
-    else if (state == delimiter_received) {
+    else
+    if (state == delimiter_received) {
         state = term_ack_sent;
         outpipe = NULL;
         send_pipe_term_ack (peer);
@@ -339,7 +307,8 @@ void zmq::pipe_t::process_pipe_term ()
     //  This is the case where both ends of the pipe are closed in parallel.
     //  We simply reply to the request by ack and continue waiting for our
     //  own ack.
-    else if (state == term_req_sent1) {
+    else
+    if (state == term_req_sent1) {
         state = term_req_sent2;
         outpipe = NULL;
         send_pipe_term_ack (peer);
@@ -359,7 +328,8 @@ void zmq::pipe_t::process_pipe_term_ack ()
     if (state == term_req_sent1) {
         outpipe = NULL;
         send_pipe_term_ack (peer);
-    } else
+    }
+    else
         zmq_assert (state == term_ack_sent || state == term_req_sent2);
 
     //  We'll deallocate the inbound pipe, the peer will deallocate the outbound
@@ -376,17 +346,12 @@ void zmq::pipe_t::process_pipe_term_ack ()
         }
     }
 
-    LIBZMQ_DELETE (inpipe);
+    delete inpipe;
 
     //  Deallocate the pipe object
     delete this;
 }
 
-void zmq::pipe_t::process_pipe_hwm (int inhwm_, int outhwm_)
-{
-    set_hwms (inhwm_, outhwm_);
-}
-
 void zmq::pipe_t::set_nodelay ()
 {
     this->delay = false;
@@ -397,49 +362,56 @@ void zmq::pipe_t::terminate (bool delay_)
     //  Overload the value specified at pipe creation.
     delay = delay_;
 
-    //  If terminate was already called, we can ignore the duplicate invocation.
-    if (state == term_req_sent1 || state == term_req_sent2) {
+    //  If terminate was already called, we can ignore the duplicit invocation.
+    if (state == term_req_sent1 || state == term_req_sent2)
         return;
-    }
+
     //  If the pipe is in the final phase of async termination, it's going to
     //  closed anyway. No need to do anything special here.
-    else if (state == term_ack_sent) {
+    else
+    if (state == term_ack_sent)
         return;
-    }
+
     //  The simple sync termination case. Ask the peer to terminate and wait
     //  for the ack.
-    else if (state == active) {
+    else
+    if (state == active) {
         send_pipe_term (peer);
         state = term_req_sent1;
     }
+
     //  There are still pending messages available, but the user calls
     //  'terminate'. We can act as if all the pending messages were read.
-    else if (state == waiting_for_delimiter && !delay) {
-        //  Drop any unfinished outbound messages.
-        rollback ();
+    else
+    if (state == waiting_for_delimiter && !delay) {
         outpipe = NULL;
         send_pipe_term_ack (peer);
         state = term_ack_sent;
     }
-    //  If there are pending messages still available, do nothing.
-    else if (state == waiting_for_delimiter) {
+
+    //  If there are pending messages still availabe, do nothing.
+    else
+    if (state == waiting_for_delimiter) {
     }
+
     //  We've already got delimiter, but not term command yet. We can ignore
     //  the delimiter and ack synchronously terminate as if we were in
     //  active state.
-    else if (state == delimiter_received) {
+    else
+    if (state == delimiter_received) {
         send_pipe_term (peer);
         state = term_req_sent1;
     }
+
     //  There are no other states.
-    else {
+    else
         zmq_assert (false);
-    }
 
     //  Stop outbound flow of messages.
     out_active = false;
 
     if (outpipe) {
+
         //  Drop any unfinished outbound messages.
         rollback ();
 
@@ -473,16 +445,22 @@ int zmq::pipe_t::compute_lwm (int hwm_)
     //     result in low performance.
     //
     //  Given the 3. it would be good to keep HWM and LWM as far apart as
-    //  possible to reduce the thread switching overhead to almost zero.
-    //  Let's make LWM 1/2 of HWM.
-    int result = (hwm_ + 1) / 2;
+    //  possible to reduce the thread switching overhead to almost zero,
+    //  say HWM-LWM should be max_wm_delta.
+    //
+    //  That done, we still we have to account for the cases where
+    //  HWM < max_wm_delta thus driving LWM to negative numbers.
+    //  Let's make LWM 1/2 of HWM in such cases.
+    int result = (hwm_ > max_wm_delta * 2) ?
+        hwm_ - max_wm_delta : (hwm_ + 1) / 2;
 
     return result;
 }
 
 void zmq::pipe_t::process_delimiter ()
 {
-    zmq_assert (state == active || state == waiting_for_delimiter);
+    zmq_assert (state == active
+            ||  state == waiting_for_delimiter);
 
     if (state == active)
         state = delimiter_received;
@@ -505,46 +483,27 @@ void zmq::pipe_t::hiccup ()
 
     //  Create new inpipe.
     if (conflate)
-        inpipe = new (std::nothrow) ypipe_conflate_t<msg_t> ();
+        inpipe = new (std::nothrow)
+            ypipe_conflate_t <msg_t> ();
     else
-        inpipe = new (std::nothrow) ypipe_t<msg_t, message_pipe_granularity> ();
+        inpipe = new (std::nothrow)
+            ypipe_t <msg_t, message_pipe_granularity> ();
 
     alloc_assert (inpipe);
     in_active = true;
 
     //  Notify the peer about the hiccup.
-    send_hiccup (peer, (void *) inpipe);
+    send_hiccup (peer, (void*) inpipe);
 }
 
 void zmq::pipe_t::set_hwms (int inhwm_, int outhwm_)
 {
-    int in = inhwm_ + (inhwmboost > 0 ? inhwmboost : 0);
-    int out = outhwm_ + (outhwmboost > 0 ? outhwmboost : 0);
-
-    // if either send or recv side has hwm <= 0 it means infinite so we should set hwms infinite
-    if (inhwm_ <= 0 || inhwmboost == 0)
-        in = 0;
-
-    if (outhwm_ <= 0 || outhwmboost == 0)
-        out = 0;
-
-    lwm = compute_lwm (in);
-    hwm = out;
-}
-
-void zmq::pipe_t::set_hwms_boost (int inhwmboost_, int outhwmboost_)
-{
-    inhwmboost = inhwmboost_;
-    outhwmboost = outhwmboost_;
+    lwm = compute_lwm (inhwm_);
+    hwm = outhwm_;
 }
 
 bool zmq::pipe_t::check_hwm () const
 {
-    bool full = hwm > 0 && msgs_written - peers_msgs_read >= uint64_t (hwm);
-    return (!full);
-}
-
-void zmq::pipe_t::send_hwms_to_peer (int inhwm_, int outhwm_)
-{
-    send_pipe_hwm (peer, inhwm_, outhwm_);
+    bool full = hwm > 0 && msgs_written - peers_msgs_read >= uint64_t (hwm - 1);
+    return( !full );
 }
