@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2007-2013 Contributors as noted in the AUTHORS file
+    Copyright (c) 2007-2014 Contributors as noted in the AUTHORS file
 
     This file is part of 0MQ.
 
@@ -18,6 +18,8 @@
 */
 
 #include "pub.hpp"
+#include "pipe.hpp"
+#include "err.hpp"
 #include "msg.hpp"
 
 zmq::pub_t::pub_t (class ctx_t *parent_, uint32_t tid_, int sid_) :
@@ -30,6 +32,17 @@ zmq::pub_t::~pub_t ()
 {
 }
 
+void zmq::pub_t::xattach_pipe (pipe_t *pipe_, bool subscribe_to_all_)
+{
+    zmq_assert (pipe_);
+
+    //  Don't delay pipe termination as there is no one
+    //  to receive the delimiter.
+    pipe_->set_nodelay ();
+
+    xpub_t::xattach_pipe (pipe_, subscribe_to_all_);
+}
+
 int zmq::pub_t::xrecv (class msg_t *)
 {
     //  Messages cannot be received from PUB socket.
