@@ -1,41 +1,36 @@
 /*
-    Copyright (c) 2007-2016 Contributors as noted in the AUTHORS file
+    Copyright (c) 2007-2014 Contributors as noted in the AUTHORS file
 
-    This file is part of libzmq, the ZeroMQ core engine in C++.
+    This file is part of 0MQ.
 
-    libzmq is free software; you can redistribute it and/or modify it under
-    the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 3 of the License, or
+    0MQ is free software; you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License as published by
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
-    As a special exception, the Contributors give you permission to link
-    this library with independent modules to produce an executable,
-    regardless of the license terms of these independent modules, and to
-    copy and distribute the resulting executable under terms of your choice,
-    provided that you also meet, for each linked independent module, the
-    terms and conditions of the license of that module. An independent
-    module is a module which is not derived from or based on this library.
-    If you modify this library, you must extend this exception to your
-    version of the library.
-
-    libzmq is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
-    License for more details.
+    0MQ is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU Lesser General Public License for more details.
 
     You should have received a copy of the GNU Lesser General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
+#include "../include/zmq.h"
+#include <errno.h>
+#include <stdlib.h>
+#include <string.h>
+#include <unistd.h>
+#include <string>
+
+#undef NDEBUG
+#include <assert.h>
+
 #include "testutil.hpp"
 
 int main (void)
 {
-    if (!is_tipc_available ()) {
-        printf ("TIPC environment unavailable, skipping test\n");
-        return 77;
-    }
-
     int val;
     int rc;
     char buffer[16];
@@ -46,29 +41,29 @@ int main (void)
     // of the messages getting queued, as connect() creates a
     // pipe immediately.
 
-    void *context = zmq_ctx_new ();
+    void *context = zmq_ctx_new();
     assert (context);
-    void *to = zmq_socket (context, ZMQ_PULL);
+    void *to = zmq_socket(context, ZMQ_PULL);
     assert (to);
 
     // Bind the one valid receiver
     val = 0;
-    rc = zmq_setsockopt (to, ZMQ_LINGER, &val, sizeof (val));
+    rc = zmq_setsockopt(to, ZMQ_LINGER, &val, sizeof(val));
     assert (rc == 0);
     rc = zmq_bind (to, "tipc://{6555,0,0}");
     assert (rc == 0);
 
     // Create a socket pushing to two endpoints - only 1 message should arrive.
     void *from = zmq_socket (context, ZMQ_PUSH);
-    assert (from);
+    assert(from);
 
     val = 0;
     zmq_setsockopt (from, ZMQ_LINGER, &val, sizeof (val));
     // This pipe will not connect
-    rc = zmq_connect (from, "tipc://{5556,0}@0.0.0");
+    rc = zmq_connect (from, "tipc://{5556,0}");
     assert (rc == 0);
     // This pipe will
-    rc = zmq_connect (from, "tipc://{6555,0}@0.0.0");
+    rc = zmq_connect (from, "tipc://{6555,0}");
     assert (rc == 0);
 
     // We send 10 messages, 5 should just get stuck in the queue
@@ -80,7 +75,7 @@ int main (void)
 
     // We now consume from the connected pipe
     // - we should see just 5
-    int timeout = 250;
+    int timeout = 100;
     rc = zmq_setsockopt (to, ZMQ_RCVTIMEO, &timeout, sizeof (int));
     assert (rc == 0);
 
@@ -88,7 +83,7 @@ int main (void)
     while (true) {
         rc = zmq_recv (to, &buffer, sizeof (buffer), 0);
         if (rc == -1)
-            break; //  Break when we didn't get a message
+            break;          //  Break when we didn't get a message
         seen++;
     }
     assert (seen == 5);
@@ -99,7 +94,7 @@ int main (void)
     rc = zmq_close (to);
     assert (rc == 0);
 
-    rc = zmq_ctx_term (context);
+    rc = zmq_term (context);
     assert (rc == 0);
 
     // TEST 2
@@ -109,7 +104,7 @@ int main (void)
     // also set the delay attach on connect flag, which should
     // cause the pipe attachment to be delayed until the connection
     // succeeds.
-    context = zmq_ctx_new ();
+    context = zmq_ctx_new();
 
     // Bind the valid socket
     to = zmq_socket (context, ZMQ_PULL);
@@ -118,7 +113,7 @@ int main (void)
     assert (rc == 0);
 
     val = 0;
-    rc = zmq_setsockopt (to, ZMQ_LINGER, &val, sizeof (val));
+    rc = zmq_setsockopt (to, ZMQ_LINGER, &val, sizeof(val));
     assert (rc == 0);
 
     // Create a socket pushing to two endpoints - all messages should arrive.
@@ -126,19 +121,19 @@ int main (void)
     assert (from);
 
     val = 0;
-    rc = zmq_setsockopt (from, ZMQ_LINGER, &val, sizeof (val));
+    rc = zmq_setsockopt (from, ZMQ_LINGER, &val, sizeof(val));
     assert (rc == 0);
 
     // Set the key flag
     val = 1;
-    rc = zmq_setsockopt (from, ZMQ_DELAY_ATTACH_ON_CONNECT, &val, sizeof (val));
+    rc = zmq_setsockopt (from, ZMQ_DELAY_ATTACH_ON_CONNECT, &val, sizeof(val));
     assert (rc == 0);
 
     // Connect to the invalid socket
-    rc = zmq_connect (from, "tipc://{5561,0}@0.0.0");
+    rc = zmq_connect (from, "tipc://{5561,0}");
     assert (rc == 0);
     // Connect to the valid socket
-    rc = zmq_connect (from, "tipc://{5560,0}@0.0.0");
+    rc = zmq_connect (from, "tipc://{5560,0}");
     assert (rc == 0);
 
     // Send 10 messages, all should be routed to the connected pipe
@@ -153,7 +148,7 @@ int main (void)
     while (true) {
         rc = zmq_recv (to, &buffer, sizeof (buffer), 0);
         if (rc == -1)
-            break; //  Break when we didn't get a message
+            break;          //  Break when we didn't get a message
         seen++;
     }
     assert (seen == 10);
@@ -164,7 +159,7 @@ int main (void)
     rc = zmq_close (to);
     assert (rc == 0);
 
-    rc = zmq_ctx_term (context);
+    rc = zmq_term (context);
     assert (rc == 0);
 
     // TEST 3
@@ -186,12 +181,11 @@ int main (void)
 
     //  Frontend connects to backend using DELAY_ATTACH_ON_CONNECT
     int on = 1;
-    rc =
-      zmq_setsockopt (frontend, ZMQ_DELAY_ATTACH_ON_CONNECT, &on, sizeof (on));
+    rc = zmq_setsockopt (frontend, ZMQ_DELAY_ATTACH_ON_CONNECT, &on, sizeof (on));
     assert (rc == 0);
     rc = zmq_bind (backend, "tipc://{5560,0,0}");
     assert (rc == 0);
-    rc = zmq_connect (frontend, "tipc://{5560,0}@0.0.0");
+    rc = zmq_connect (frontend, "tipc://{5560,0}");
     assert (rc == 0);
 
     //  Ping backend to frontend so we know when the connection is up
@@ -238,6 +232,7 @@ int main (void)
     rc = zmq_close (frontend);
     assert (rc == 0);
 
-    rc = zmq_ctx_term (context);
+    rc = zmq_term (context);
     assert (rc == 0);
 }
+
