@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2007-2013 Contributors as noted in the AUTHORS file
+    Copyright (c) 2007-2014 Contributors as noted in the AUTHORS file
 
     This file is part of 0MQ.
 
@@ -24,7 +24,7 @@ static void pusher (void *ctx)
     // Connect first
     void *connectSocket = zmq_socket (ctx, ZMQ_PAIR);
     assert (connectSocket);
-    int rc = zmq_connect (connectSocket, "inproc://a");
+    int rc = zmq_connect (connectSocket, "inproc://sink");
     assert (rc == 0);
 
     // Queue up some data
@@ -36,7 +36,41 @@ static void pusher (void *ctx)
     assert (rc == 0);
 }
 
-void test_bind_before_connect()
+static void simult_conn (void *payload)
+{
+    // Pull out arguments - context followed by endpoint string
+    void* ctx   = (void*)((void**)payload)[0];
+    char* endpt = (char*)((void**)payload)[1];
+
+    // Connect
+    void *connectSocket = zmq_socket (ctx, ZMQ_SUB);
+    assert (connectSocket);
+    int rc = zmq_connect (connectSocket, endpt);
+    assert (rc == 0);
+
+    // Cleanup
+    rc = zmq_close (connectSocket);
+    assert (rc == 0);
+}
+
+static void simult_bind (void *payload)
+{
+    // Pull out arguments - context followed by endpoint string
+    void* ctx   = (void*)((void**)payload)[0];
+    char* endpt = (char*)((void**)payload)[1];
+
+    // Bind
+    void *bindSocket = zmq_socket (ctx, ZMQ_PUB);
+    assert (bindSocket);
+    int rc = zmq_bind (bindSocket, endpt);
+    assert (rc == 0);
+
+    // Cleanup
+    rc = zmq_close (bindSocket);
+    assert (rc == 0);
+}
+
+void test_bind_before_connect ()
 {
     void *ctx = zmq_ctx_new ();
     assert (ctx);
@@ -44,15 +78,15 @@ void test_bind_before_connect()
     // Bind first
     void *bindSocket = zmq_socket (ctx, ZMQ_PAIR);
     assert (bindSocket);
-    int rc = zmq_bind (bindSocket, "inproc://a");
+    int rc = zmq_bind (bindSocket, "inproc://bbc");
     assert (rc == 0);
 
     // Now connect
     void *connectSocket = zmq_socket (ctx, ZMQ_PAIR);
     assert (connectSocket);
-    rc = zmq_connect (connectSocket, "inproc://a");
+    rc = zmq_connect (connectSocket, "inproc://bbc");
     assert (rc == 0);
-    
+
     // Queue up some data
     rc = zmq_send_const (connectSocket, "foobar", 6, 0);
     assert (rc == 6);
@@ -77,7 +111,7 @@ void test_bind_before_connect()
     assert (rc == 0);
 }
 
-void test_connect_before_bind()
+void test_connect_before_bind ()
 {
     void *ctx = zmq_ctx_new ();
     assert (ctx);
@@ -85,7 +119,7 @@ void test_connect_before_bind()
     // Connect first
     void *connectSocket = zmq_socket (ctx, ZMQ_PAIR);
     assert (connectSocket);
-    int rc = zmq_connect (connectSocket, "inproc://a");
+    int rc = zmq_connect (connectSocket, "inproc://cbb");
     assert (rc == 0);
 
     // Queue up some data
@@ -95,9 +129,9 @@ void test_connect_before_bind()
     // Now bind
     void *bindSocket = zmq_socket (ctx, ZMQ_PAIR);
     assert (bindSocket);
-    rc = zmq_bind (bindSocket, "inproc://a");
+    rc = zmq_bind (bindSocket, "inproc://cbb");
     assert (rc == 0);
-    
+
     // Read pending message
     zmq_msg_t msg;
     rc = zmq_msg_init (&msg);
@@ -118,7 +152,7 @@ void test_connect_before_bind()
     assert (rc == 0);
 }
 
-void test_connect_before_bind_pub_sub()
+void test_connect_before_bind_pub_sub ()
 {
     void *ctx = zmq_ctx_new ();
     assert (ctx);
@@ -126,7 +160,7 @@ void test_connect_before_bind_pub_sub()
     // Connect first
     void *connectSocket = zmq_socket (ctx, ZMQ_PUB);
     assert (connectSocket);
-    int rc = zmq_connect (connectSocket, "inproc://a");
+    int rc = zmq_connect (connectSocket, "inproc://cbbps");
     assert (rc == 0);
 
     // Queue up some data, this will be dropped
@@ -138,9 +172,9 @@ void test_connect_before_bind_pub_sub()
     assert (bindSocket);
     rc = zmq_setsockopt (bindSocket, ZMQ_SUBSCRIBE, "", 0);
     assert (rc == 0);
-    rc = zmq_bind (bindSocket, "inproc://a");
+    rc = zmq_bind (bindSocket, "inproc://cbbps");
     assert (rc == 0);
-   
+
     // Wait for pub-sub connection to happen
     msleep (SETTLE_TIME);
 
@@ -168,21 +202,21 @@ void test_connect_before_bind_pub_sub()
     assert (rc == 0);
 }
 
-void test_multiple_connects()
+void test_multiple_connects ()
 {
     const unsigned int no_of_connects = 10;
     void *ctx = zmq_ctx_new ();
     assert (ctx);
 
     int rc;
-    void *connectSocket[no_of_connects];
+    void *connectSocket [no_of_connects];
 
     // Connect first
     for (unsigned int i = 0; i < no_of_connects; ++i)
     {
         connectSocket [i] = zmq_socket (ctx, ZMQ_PUSH);
         assert (connectSocket [i]);
-        rc = zmq_connect (connectSocket [i], "inproc://a");
+        rc = zmq_connect (connectSocket [i], "inproc://multiple");
         assert (rc == 0);
 
         // Queue up some data
@@ -193,9 +227,9 @@ void test_multiple_connects()
     // Now bind
     void *bindSocket = zmq_socket (ctx, ZMQ_PULL);
     assert (bindSocket);
-    rc = zmq_bind (bindSocket, "inproc://a");
+    rc = zmq_bind (bindSocket, "inproc://multiple");
     assert (rc == 0);
-    
+
     for (unsigned int i = 0; i < no_of_connects; ++i)
     {
         // Read pending message
@@ -222,7 +256,7 @@ void test_multiple_connects()
     assert (rc == 0);
 }
 
-void test_multiple_threads()
+void test_multiple_threads ()
 {
     const unsigned int no_of_threads = 30;
     void *ctx = zmq_ctx_new ();
@@ -240,7 +274,7 @@ void test_multiple_threads()
     // Now bind
     void *bindSocket = zmq_socket (ctx, ZMQ_PULL);
     assert (bindSocket);
-    rc = zmq_bind (bindSocket, "inproc://a");
+    rc = zmq_bind (bindSocket, "inproc://sink");
     assert (rc == 0);
 
     for (unsigned int i = 0; i < no_of_threads; ++i)
@@ -268,22 +302,58 @@ void test_multiple_threads()
     assert (rc == 0);
 }
 
-void test_identity()
+void test_simultaneous_connect_bind_threads ()
+{
+    const unsigned int no_of_times = 50;
+    void *ctx = zmq_ctx_new ();
+    assert (ctx);
+
+    void *threads[no_of_times*2];
+    void *thr_args[no_of_times][2];
+    char endpts[no_of_times][20];
+
+    // Set up thread arguments: context followed by endpoint string
+    for (unsigned int i = 0; i < no_of_times; ++i)
+    {
+        thr_args[i][0] = (void*) ctx;
+        thr_args[i][1] = (void*) endpts[i];
+        sprintf (endpts[i], "inproc://foo_%d", i);
+    }
+
+    // Spawn all threads as simultaneously as possible
+    for (unsigned int i = 0; i < no_of_times; ++i)
+    {
+        threads[i*2+0] = zmq_threadstart (&simult_conn, (void*)thr_args[i]);
+        threads[i*2+1] = zmq_threadstart (&simult_bind, (void*)thr_args[i]);
+    }
+
+    // Close all threads
+    for (unsigned int i = 0; i < no_of_times; ++i)
+    {
+        zmq_threadclose (threads[i*2+0]);
+        zmq_threadclose (threads[i*2+1]);
+    }
+
+    int rc = zmq_ctx_term (ctx);
+    assert (rc == 0);
+}
+
+void test_identity ()
 {
     //  Create the infrastructure
     void *ctx = zmq_ctx_new ();
     assert (ctx);
-    
+
     void *sc = zmq_socket (ctx, ZMQ_DEALER);
     assert (sc);
-    
-    int rc = zmq_connect (sc, "inproc://a");
+
+    int rc = zmq_connect (sc, "inproc://identity");
     assert (rc == 0);
-   
+
     void *sb = zmq_socket (ctx, ZMQ_ROUTER);
     assert (sb);
-    
-    rc = zmq_bind (sb, "inproc://a");
+
+    rc = zmq_bind (sb, "inproc://identity");
     assert (rc == 0);
 
     //  Send 2-part message.
@@ -316,24 +386,94 @@ void test_identity()
     //  Deallocate the infrastructure.
     rc = zmq_close (sc);
     assert (rc == 0);
-    
+
     rc = zmq_close (sb);
     assert (rc == 0);
-    
+
+    rc = zmq_ctx_term (ctx);
+    assert (rc == 0);
+}
+
+void test_connect_only ()
+{
+    void *ctx = zmq_ctx_new ();
+    assert (ctx);
+
+    void *connectSocket = zmq_socket (ctx, ZMQ_PUSH);
+    assert (connectSocket);
+    int rc = zmq_connect (connectSocket, "inproc://a");
+    assert (rc == 0);
+
+    rc = zmq_close (connectSocket);
+    assert (rc == 0);
+
+    rc = zmq_ctx_term (ctx);
+    assert (rc == 0);
+}
+
+
+void test_unbind ()
+{
+    void *ctx = zmq_ctx_new ();
+    assert (ctx);
+
+    // Bind and unbind socket 1
+    void *bindSocket1 = zmq_socket (ctx, ZMQ_PAIR);
+    assert (bindSocket1);
+    int rc = zmq_bind (bindSocket1, "inproc://unbind");
+    assert (rc == 0);
+    zmq_unbind (bindSocket1, "inproc://unbind");
+    assert (rc == 0);
+
+    // Bind socket 2
+    void *bindSocket2 = zmq_socket (ctx, ZMQ_PAIR);
+    assert (bindSocket2);
+    rc = zmq_bind (bindSocket2, "inproc://unbind");
+    assert (rc == 0);
+
+    // Now connect
+    void *connectSocket = zmq_socket (ctx, ZMQ_PAIR);
+    assert (connectSocket);
+    rc = zmq_connect (connectSocket, "inproc://unbind");
+    assert (rc == 0);
+
+    // Queue up some data
+    rc = zmq_send_const (connectSocket, "foobar", 6, 0);
+    assert (rc == 6);
+
+    // Read pending message
+    zmq_msg_t msg;
+    rc = zmq_msg_init (&msg);
+    assert (rc == 0);
+    rc = zmq_msg_recv (&msg, bindSocket2, 0);
+    assert (rc == 6);
+    void *data = zmq_msg_data (&msg);
+    assert (memcmp ("foobar", data, 6) == 0);
+
+    // Cleanup
+    rc = zmq_close (connectSocket);
+    assert (rc == 0);
+    rc = zmq_close (bindSocket1);
+    assert (rc == 0);
+    rc = zmq_close (bindSocket2);
+    assert (rc == 0);
     rc = zmq_ctx_term (ctx);
     assert (rc == 0);
 }
 
 int main (void)
 {
-    setup_test_environment();
+    setup_test_environment ();
 
     test_bind_before_connect ();
     test_connect_before_bind ();
     test_connect_before_bind_pub_sub ();
     test_multiple_connects ();
     test_multiple_threads ();
+    test_simultaneous_connect_bind_threads ();
     test_identity ();
+    test_connect_only ();
+    test_unbind ();
 
     return 0;
 }
