@@ -1,27 +1,17 @@
 /*
-    Copyright (c) 2007-2017 Contributors as noted in the AUTHORS file
+    Copyright (c) 2007-2014 Contributors as noted in the AUTHORS file
 
-    This file is part of libzmq, the ZeroMQ core engine in C++.
+    This file is part of 0MQ.
 
-    libzmq is free software; you can redistribute it and/or modify it under
-    the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 3 of the License, or
+    0MQ is free software; you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License as published by
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
-    As a special exception, the Contributors give you permission to link
-    this library with independent modules to produce an executable,
-    regardless of the license terms of these independent modules, and to
-    copy and distribute the resulting executable under terms of your choice,
-    provided that you also meet, for each linked independent module, the
-    terms and conditions of the license of that module. An independent
-    module is a module which is not derived from or based on this library.
-    If you modify this library, you must extend this exception to your
-    version of the library.
-
-    libzmq is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
-    License for more details.
+    0MQ is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU Lesser General Public License for more details.
 
     You should have received a copy of the GNU Lesser General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
@@ -29,26 +19,29 @@
 
 #include "testutil.hpp"
 
-static void zap_handler (void *handler)
+static void
+zap_handler (void *handler)
 {
-    uint8_t metadata[] = {5, 'H', 'e', 'l', 'l', 'o', 0,  0,
-                          0, 5,   'W', 'o', 'r', 'l', 'd'};
+    uint8_t metadata [] = {
+        5, 'H', 'e', 'l', 'l', 'o',
+        0, 0, 0, 5, 'W', 'o', 'r', 'l', 'd'
+    };
 
     //  Process ZAP requests forever
     while (true) {
         char *version = s_recv (handler);
         if (!version)
-            break; //  Terminating
+            break;          //  Terminating
 
         char *sequence = s_recv (handler);
         char *domain = s_recv (handler);
         char *address = s_recv (handler);
-        char *routing_id = s_recv (handler);
+        char *identity = s_recv (handler);
         char *mechanism = s_recv (handler);
 
         assert (streq (version, "1.0"));
         assert (streq (mechanism, "NULL"));
-
+        
         s_sendmore (handler, version);
         s_sendmore (handler, sequence);
         if (streq (domain, "DOMAIN")) {
@@ -56,17 +49,18 @@ static void zap_handler (void *handler)
             s_sendmore (handler, "OK");
             s_sendmore (handler, "anonymous");
             zmq_send (handler, metadata, sizeof (metadata), 0);
-        } else {
+        }
+        else {
             s_sendmore (handler, "400");
             s_sendmore (handler, "BAD DOMAIN");
             s_sendmore (handler, "");
-            s_send (handler, "");
+            s_send     (handler, "");
         }
         free (version);
         free (sequence);
         free (domain);
         free (address);
-        free (routing_id);
+        free (identity);
         free (mechanism);
     }
     close_zero_linger (handler);
@@ -74,9 +68,7 @@ static void zap_handler (void *handler)
 
 int main (void)
 {
-    setup_test_environment ();
-    size_t len = MAX_SOCKET_STRING;
-    char my_endpoint[MAX_SOCKET_STRING];
+    setup_test_environment();
     void *ctx = zmq_ctx_new ();
     assert (ctx);
 
@@ -95,11 +87,9 @@ int main (void)
     assert (client);
     rc = zmq_setsockopt (server, ZMQ_ZAP_DOMAIN, "DOMAIN", 6);
     assert (rc == 0);
-    rc = zmq_bind (server, "tcp://127.0.0.1:*");
+    rc = zmq_bind (server, "tcp://127.0.0.1:9001");
     assert (rc == 0);
-    rc = zmq_getsockopt (server, ZMQ_LAST_ENDPOINT, my_endpoint, &len);
-    assert (rc == 0);
-    rc = zmq_connect (client, my_endpoint);
+    rc = zmq_connect (client, "tcp://127.0.0.1:9001");
     assert (rc == 0);
 
     s_send (client, "This is a message");
@@ -111,7 +101,6 @@ int main (void)
     assert (streq (zmq_msg_gets (&msg, "Socket-Type"), "DEALER"));
     assert (streq (zmq_msg_gets (&msg, "User-Id"), "anonymous"));
     assert (streq (zmq_msg_gets (&msg, "Peer-Address"), "127.0.0.1"));
-
     assert (zmq_msg_gets (&msg, "No Such") == NULL);
     assert (zmq_errno () == EINVAL);
     zmq_msg_close (&msg);
