@@ -1,27 +1,17 @@
 /*
-    Copyright (c) 2007-2017 Contributors as noted in the AUTHORS file
+    Copyright (c) 2007-2014 Contributors as noted in the AUTHORS file
 
-    This file is part of libzmq, the ZeroMQ core engine in C++.
+    This file is part of 0MQ.
 
-    libzmq is free software; you can redistribute it and/or modify it under
-    the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 3 of the License, or
+    0MQ is free software; you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License as published by
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
-    As a special exception, the Contributors give you permission to link
-    this library with independent modules to produce an executable,
-    regardless of the license terms of these independent modules, and to
-    copy and distribute the resulting executable under terms of your choice,
-    provided that you also meet, for each linked independent module, the
-    terms and conditions of the license of that module. An independent
-    module is a module which is not derived from or based on this library.
-    If you modify this library, you must extend this exception to your
-    version of the library.
-
-    libzmq is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
-    License for more details.
+    0MQ is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU Lesser General Public License for more details.
 
     You should have received a copy of the GNU Lesser General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
@@ -30,7 +20,7 @@
 #include "testutil.hpp"
 
 const char *bind_address = 0;
-char connect_address[MAX_SOCKET_STRING];
+const char *connect_address = 0;
 
 void test_push_round_robin_out (void *ctx)
 {
@@ -39,26 +29,24 @@ void test_push_round_robin_out (void *ctx)
 
     int rc = zmq_bind (push, bind_address);
     assert (rc == 0);
-    size_t len = MAX_SOCKET_STRING;
-    rc = zmq_getsockopt (push, ZMQ_LAST_ENDPOINT, connect_address, &len);
-    assert (rc == 0);
 
     const size_t services = 5;
-    void *pulls[services];
+    void *pulls [services];
     for (size_t peer = 0; peer < services; ++peer) {
-        pulls[peer] = zmq_socket (ctx, ZMQ_PULL);
-        assert (pulls[peer]);
+        pulls [peer] = zmq_socket (ctx, ZMQ_PULL);
+        assert (pulls [peer]);
 
-        int timeout = 250;
-        rc = zmq_setsockopt (pulls[peer], ZMQ_RCVTIMEO, &timeout, sizeof (int));
+        int timeout = 100;
+        rc = zmq_setsockopt (pulls [peer], ZMQ_RCVTIMEO, &timeout, sizeof (int));
         assert (rc == 0);
 
-        rc = zmq_connect (pulls[peer], connect_address);
+        rc = zmq_connect (pulls [peer], connect_address);
         assert (rc == 0);
     }
 
     // Wait for connections.
-    msleep (SETTLE_TIME);
+    rc = zmq_poll (0, 0, 100);
+    assert (rc == 0);
 
     // Send 2N messages
     for (size_t peer = 0; peer < services; ++peer)
@@ -68,17 +56,18 @@ void test_push_round_robin_out (void *ctx)
 
     // Expect every PULL got one of each
     for (size_t peer = 0; peer < services; ++peer) {
-        s_recv_seq (pulls[peer], "ABC", SEQ_END);
-        s_recv_seq (pulls[peer], "DEF", SEQ_END);
+        s_recv_seq (pulls [peer], "ABC", SEQ_END);
+        s_recv_seq (pulls [peer], "DEF", SEQ_END);
     }
 
     close_zero_linger (push);
 
     for (size_t peer = 0; peer < services; ++peer)
-        close_zero_linger (pulls[peer]);
+        close_zero_linger (pulls [peer]);
 
     // Wait for disconnects.
-    msleep (SETTLE_TIME);
+    rc = zmq_poll (0, 0, 100);
+    assert (rc == 0);
 }
 
 void test_pull_fair_queue_in (void *ctx)
@@ -88,43 +77,43 @@ void test_pull_fair_queue_in (void *ctx)
 
     int rc = zmq_bind (pull, bind_address);
     assert (rc == 0);
-    size_t len = MAX_SOCKET_STRING;
-    rc = zmq_getsockopt (pull, ZMQ_LAST_ENDPOINT, connect_address, &len);
-    assert (rc == 0);
 
     const size_t services = 5;
-    void *pushs[services];
-    for (size_t peer = 0; peer < services; ++peer) {
-        pushs[peer] = zmq_socket (ctx, ZMQ_PUSH);
-        assert (pushs[peer]);
+    void *pushs [services];
+    for (size_t peer = 0; peer < services; ++peer)
+    {
+        pushs [peer] = zmq_socket (ctx, ZMQ_PUSH);
+        assert (pushs [peer]);
 
-        rc = zmq_connect (pushs[peer], connect_address);
+        rc = zmq_connect (pushs [peer], connect_address);
         assert (rc == 0);
     }
 
     // Wait for connections.
-    msleep (SETTLE_TIME);
+    rc = zmq_poll (0, 0, 100);
+    assert (rc == 0);
 
     int first_half = 0;
     int second_half = 0;
 
     // Send 2N messages
     for (size_t peer = 0; peer < services; ++peer) {
-        char *str = strdup ("A");
+        char *str = strdup("A");
 
-        str[0] += peer;
-        s_send_seq (pushs[peer], str, SEQ_END);
-        first_half += str[0];
+        str [0] += peer;
+        s_send_seq (pushs [peer], str, SEQ_END);
+        first_half += str [0];
 
-        str[0] += services;
-        s_send_seq (pushs[peer], str, SEQ_END);
-        second_half += str[0];
+        str [0] += services;
+        s_send_seq (pushs [peer], str, SEQ_END);
+        second_half += str [0];
 
         free (str);
     }
 
     // Wait for data.
-    msleep (SETTLE_TIME);
+    rc = zmq_poll (0, 0, 100);
+    assert (rc == 0);
 
     zmq_msg_t msg;
     rc = zmq_msg_init (&msg);
@@ -134,8 +123,8 @@ void test_pull_fair_queue_in (void *ctx)
     for (size_t peer = 0; peer < services; ++peer) {
         rc = zmq_msg_recv (&msg, pull, 0);
         assert (rc == 2);
-        const char *str = (const char *) zmq_msg_data (&msg);
-        first_half -= str[0];
+        const char *str = (const char *)zmq_msg_data (&msg);
+        first_half -= str [0];
     }
     assert (first_half == 0);
 
@@ -143,8 +132,8 @@ void test_pull_fair_queue_in (void *ctx)
     for (size_t peer = 0; peer < services; ++peer) {
         rc = zmq_msg_recv (&msg, pull, 0);
         assert (rc == 2);
-        const char *str = (const char *) zmq_msg_data (&msg);
-        second_half -= str[0];
+        const char *str = (const char *)zmq_msg_data (&msg);
+        second_half -= str [0];
     }
     assert (second_half == 0);
 
@@ -154,10 +143,11 @@ void test_pull_fair_queue_in (void *ctx)
     close_zero_linger (pull);
 
     for (size_t peer = 0; peer < services; ++peer)
-        close_zero_linger (pushs[peer]);
+        close_zero_linger (pushs [peer]);
 
     // Wait for disconnects.
-    msleep (SETTLE_TIME);
+    rc = zmq_poll (0, 0, 100);
+    assert (rc == 0);
 }
 
 void test_push_block_on_send_no_peers (void *ctx)
@@ -165,7 +155,7 @@ void test_push_block_on_send_no_peers (void *ctx)
     void *sc = zmq_socket (ctx, ZMQ_PUSH);
     assert (sc);
 
-    int timeout = 250;
+    int timeout = 100;
     int rc = zmq_setsockopt (sc, ZMQ_SNDTIMEO, &timeout, sizeof (timeout));
     assert (rc == 0);
 
@@ -192,9 +182,6 @@ void test_destroy_queue_on_disconnect (void *ctx)
 
     rc = zmq_bind (A, bind_address);
     assert (rc == 0);
-    size_t len = MAX_SOCKET_STRING;
-    rc = zmq_getsockopt (A, ZMQ_LAST_ENDPOINT, connect_address, &len);
-    assert (rc == 0);
 
     void *B = zmq_socket (ctx, ZMQ_PULL);
     assert (B);
@@ -219,7 +206,7 @@ void test_destroy_queue_on_disconnect (void *ctx)
     assert (rc == 0);
 
     // Disconnect may take time and need command processing.
-    zmq_pollitem_t poller[2] = {{A, 0, 0, 0}, {B, 0, 0, 0}};
+    zmq_pollitem_t poller [2] = { { A, 0, 0, 0 }, { B, 0, 0, 0 } };
     rc = zmq_poll (poller, 2, 100);
     assert (rc == 0);
     rc = zmq_poll (poller, 2, 100);
@@ -263,19 +250,22 @@ void test_destroy_queue_on_disconnect (void *ctx)
     close_zero_linger (B);
 
     // Wait for disconnects.
-    msleep (SETTLE_TIME);
+    rc = zmq_poll (0, 0, 100);
+    assert (rc == 0);
 }
 
 int main (void)
 {
-    setup_test_environment ();
+    setup_test_environment();
     void *ctx = zmq_ctx_new ();
     assert (ctx);
 
-    const char *binds[] = {"inproc://a", "tcp://127.0.0.1:*"};
+    const char *binds [] = { "inproc://a", "tcp://127.0.0.1:5555" };
+    const char *connects [] = { "inproc://a", "tcp://localhost:5555" };
 
     for (int transport = 0; transport < 2; ++transport) {
-        bind_address = binds[transport];
+        bind_address = binds [transport];
+        connect_address = connects [transport];
 
         // PUSH: SHALL route outgoing messages to connected peers using a
         // round-robin strategy.
@@ -299,5 +289,5 @@ int main (void)
     int rc = zmq_ctx_term (ctx);
     assert (rc == 0);
 
-    return 0;
+    return 0 ;
 }
