@@ -1,27 +1,17 @@
 /*
-    Copyright (c) 2007-2017 Contributors as noted in the AUTHORS file
+    Copyright (c) 2007-2014 Contributors as noted in the AUTHORS file
 
-    This file is part of libzmq, the ZeroMQ core engine in C++.
+    This file is part of 0MQ.
 
-    libzmq is free software; you can redistribute it and/or modify it under
-    the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 3 of the License, or
+    0MQ is free software; you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License as published by
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
-    As a special exception, the Contributors give you permission to link
-    this library with independent modules to produce an executable,
-    regardless of the license terms of these independent modules, and to
-    copy and distribute the resulting executable under terms of your choice,
-    provided that you also meet, for each linked independent module, the
-    terms and conditions of the license of that module. An independent
-    module is a module which is not derived from or based on this library.
-    If you modify this library, you must extend this exception to your
-    version of the library.
-
-    libzmq is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
-    License for more details.
+    0MQ is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU Lesser General Public License for more details.
 
     You should have received a copy of the GNU Lesser General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
@@ -30,7 +20,7 @@
 #include "testutil.hpp"
 
 const char *bind_address = 0;
-char connect_address[MAX_SOCKET_STRING];
+const char *connect_address = 0;
 
 void test_round_robin_out (void *ctx)
 {
@@ -39,42 +29,40 @@ void test_round_robin_out (void *ctx)
 
     int rc = zmq_bind (req, bind_address);
     assert (rc == 0);
-    size_t len = MAX_SOCKET_STRING;
-    rc = zmq_getsockopt (req, ZMQ_LAST_ENDPOINT, connect_address, &len);
-    assert (rc == 0);
 
     const size_t services = 5;
-    void *rep[services];
+    void *rep [services];
     for (size_t peer = 0; peer < services; peer++) {
-        rep[peer] = zmq_socket (ctx, ZMQ_REP);
-        assert (rep[peer]);
+        rep [peer] = zmq_socket (ctx, ZMQ_REP);
+        assert (rep [peer]);
 
-        int timeout = 250;
-        rc = zmq_setsockopt (rep[peer], ZMQ_RCVTIMEO, &timeout, sizeof (int));
+        int timeout = 100;
+        rc = zmq_setsockopt (rep [peer], ZMQ_RCVTIMEO, &timeout, sizeof (int));
         assert (rc == 0);
 
-        rc = zmq_connect (rep[peer], connect_address);
+        rc = zmq_connect (rep [peer], connect_address);
         assert (rc == 0);
     }
-    //  We have to give the connects time to finish otherwise the requests
+    //  We have to give the connects time to finish otherwise the requests 
     //  will not properly round-robin. We could alternatively connect the
     //  REQ sockets to the REP sockets.
     msleep (SETTLE_TIME);
-
+    
     // Send our peer-replies, and expect every REP it used once in order
     for (size_t peer = 0; peer < services; peer++) {
         s_send_seq (req, "ABC", SEQ_END);
-        s_recv_seq (rep[peer], "ABC", SEQ_END);
-        s_send_seq (rep[peer], "DEF", SEQ_END);
+        s_recv_seq (rep [peer], "ABC", SEQ_END);
+        s_send_seq (rep [peer], "DEF", SEQ_END);
         s_recv_seq (req, "DEF", SEQ_END);
     }
 
     close_zero_linger (req);
     for (size_t peer = 0; peer < services; peer++)
-        close_zero_linger (rep[peer]);
+        close_zero_linger (rep [peer]);
 
     // Wait for disconnects.
-    msleep (SETTLE_TIME);
+    rc = zmq_poll (0, 0, 100);
+    assert (rc == 0);
 }
 
 void test_req_only_listens_to_current_peer (void *ctx)
@@ -82,38 +70,34 @@ void test_req_only_listens_to_current_peer (void *ctx)
     void *req = zmq_socket (ctx, ZMQ_REQ);
     assert (req);
 
-    int rc = zmq_setsockopt (req, ZMQ_ROUTING_ID, "A", 2);
+    int rc = zmq_setsockopt(req, ZMQ_IDENTITY, "A", 2);
     assert (rc == 0);
 
     rc = zmq_bind (req, bind_address);
     assert (rc == 0);
-    size_t len = MAX_SOCKET_STRING;
-    rc = zmq_getsockopt (req, ZMQ_LAST_ENDPOINT, connect_address, &len);
-    assert (rc == 0);
 
     const size_t services = 3;
-    void *router[services];
-
+    void *router [services];
+    
     for (size_t i = 0; i < services; ++i) {
-        router[i] = zmq_socket (ctx, ZMQ_ROUTER);
-        assert (router[i]);
+        router [i] = zmq_socket (ctx, ZMQ_ROUTER);
+        assert (router [i]);
 
-        int timeout = 250;
-        rc =
-          zmq_setsockopt (router[i], ZMQ_RCVTIMEO, &timeout, sizeof (timeout));
+        int timeout = 100;
+        rc = zmq_setsockopt (router [i], ZMQ_RCVTIMEO, &timeout, sizeof (timeout));
         assert (rc == 0);
 
         int enabled = 1;
-        rc = zmq_setsockopt (router[i], ZMQ_ROUTER_MANDATORY, &enabled,
-                             sizeof (enabled));
+        rc = zmq_setsockopt (router [i], ZMQ_ROUTER_MANDATORY, &enabled, sizeof (enabled));
         assert (rc == 0);
 
-        rc = zmq_connect (router[i], connect_address);
+        rc = zmq_connect (router [i], connect_address);
         assert (rc == 0);
     }
 
     // Wait for connects to finish.
-    msleep (SETTLE_TIME);
+    rc = zmq_poll (0, 0, 100);
+    assert (rc == 0);
 
     for (size_t i = 0; i < services; ++i) {
         // There still is a race condition when a stale peer's message
@@ -125,13 +109,13 @@ void test_req_only_listens_to_current_peer (void *ctx)
         s_send_seq (req, "ABC", SEQ_END);
 
         // Receive on router i
-        s_recv_seq (router[i], "A", 0, "ABC", SEQ_END);
+        s_recv_seq (router [i], "A", 0, "ABC", SEQ_END);
 
         // Send back replies on all routers
         for (size_t j = 0; j < services; ++j) {
-            const char *replies[] = {"WRONG", "GOOD"};
-            const char *reply = replies[i == j ? 1 : 0];
-            s_send_seq (router[j], "A", 0, reply, SEQ_END);
+            const char *replies [] = { "WRONG", "GOOD" };
+            const char *reply = replies [i == j ? 1 : 0];
+            s_send_seq (router [j], "A", 0, reply, SEQ_END);
         }
 
         // Receive only the good reply
@@ -140,10 +124,11 @@ void test_req_only_listens_to_current_peer (void *ctx)
 
     close_zero_linger (req);
     for (size_t i = 0; i < services; ++i)
-        close_zero_linger (router[i]);
+        close_zero_linger (router [i]);
 
     // Wait for disconnects.
-    msleep (SETTLE_TIME);
+    rc = zmq_poll (0, 0, 100);
+    assert (rc == 0);
 }
 
 void test_req_message_format (void *ctx)
@@ -156,9 +141,6 @@ void test_req_message_format (void *ctx)
 
     int rc = zmq_bind (req, bind_address);
     assert (rc == 0);
-    size_t len = MAX_SOCKET_STRING;
-    rc = zmq_getsockopt (req, ZMQ_LAST_ENDPOINT, connect_address, &len);
-    assert (rc == 0);
 
     rc = zmq_connect (router, connect_address);
     assert (rc == 0);
@@ -169,7 +151,7 @@ void test_req_message_format (void *ctx)
     zmq_msg_t msg;
     zmq_msg_init (&msg);
 
-    // Receive peer routing id
+    // Receive peer identity
     rc = zmq_msg_recv (&msg, router, 0);
     assert (rc != -1);
     assert (zmq_msg_size (&msg) > 0);
@@ -204,7 +186,8 @@ void test_req_message_format (void *ctx)
     close_zero_linger (router);
 
     // Wait for disconnects.
-    msleep (SETTLE_TIME);
+    rc = zmq_poll (0, 0, 100);
+    assert (rc == 0);
 }
 
 void test_block_on_send_no_peers (void *ctx)
@@ -212,7 +195,7 @@ void test_block_on_send_no_peers (void *ctx)
     void *sc = zmq_socket (ctx, ZMQ_REQ);
     assert (sc);
 
-    int timeout = 250;
+    int timeout = 100;
     int rc = zmq_setsockopt (sc, ZMQ_SNDTIMEO, &timeout, sizeof (timeout));
     assert (rc == 0);
 
@@ -230,14 +213,16 @@ void test_block_on_send_no_peers (void *ctx)
 
 int main (void)
 {
-    setup_test_environment ();
+    setup_test_environment();
     void *ctx = zmq_ctx_new ();
     assert (ctx);
 
-    const char *binds[] = {"inproc://a", "tcp://127.0.0.1:*"};
+    const char *binds [] = { "inproc://a", "tcp://127.0.0.1:5555" };
+    const char *connects [] = { "inproc://a", "tcp://localhost:5555" };
 
     for (int transport = 0; transport < 2; transport++) {
-        bind_address = binds[transport];
+        bind_address = binds [transport];
+        connect_address = connects [transport];
 
         // SHALL route outgoing messages to connected peers using a round-robin
         // strategy.
@@ -249,7 +234,7 @@ int main (void)
         //   application.
         test_req_message_format (ctx);
 
-        // SHALL block on sending, or return a suitable error, when it has no
+        // SHALL block on sending, or return a suitable error, when it has no 
         // connected peers.
         test_block_on_send_no_peers (ctx);
 
@@ -264,5 +249,5 @@ int main (void)
     int rc = zmq_ctx_term (ctx);
     assert (rc == 0);
 
-    return 0;
+    return 0 ;
 }
