@@ -1,27 +1,17 @@
 /*
-    Copyright (c) 2007-2017 Contributors as noted in the AUTHORS file
+    Copyright (c) 2007-2014 Contributors as noted in the AUTHORS file
 
-    This file is part of libzmq, the ZeroMQ core engine in C++.
+    This file is part of 0MQ.
 
-    libzmq is free software; you can redistribute it and/or modify it under
-    the terms of the GNU Lesser General Public License (LGPL) as published
-    by the Free Software Foundation; either version 3 of the License, or
+    0MQ is free software; you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License as published by
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
-    As a special exception, the Contributors give you permission to link
-    this library with independent modules to produce an executable,
-    regardless of the license terms of these independent modules, and to
-    copy and distribute the resulting executable under terms of your choice,
-    provided that you also meet, for each linked independent module, the
-    terms and conditions of the license of that module. An independent
-    module is a module which is not derived from or based on this library.
-    If you modify this library, you must extend this exception to your
-    version of the library.
-
-    libzmq is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
-    License for more details.
+    0MQ is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU Lesser General Public License for more details.
 
     You should have received a copy of the GNU Lesser General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
@@ -31,38 +21,30 @@
 
 int main (void)
 {
-    setup_test_environment ();
-    size_t len = MAX_SOCKET_STRING;
-    char endpoint1[MAX_SOCKET_STRING];
-    char endpoint2[MAX_SOCKET_STRING];
+    setup_test_environment();
     void *ctx = zmq_ctx_new ();
     assert (ctx);
 
     //  First, create an intermediate device
     void *xpub = zmq_socket (ctx, ZMQ_XPUB);
     assert (xpub);
-    int rc = zmq_bind (xpub, "tcp://127.0.0.1:*");
-    assert (rc == 0);
-    rc = zmq_getsockopt (xpub, ZMQ_LAST_ENDPOINT, endpoint1, &len);
+    int rc = zmq_bind (xpub, "tcp://127.0.0.1:5560");
     assert (rc == 0);
     void *xsub = zmq_socket (ctx, ZMQ_XSUB);
     assert (xsub);
-    rc = zmq_bind (xsub, "tcp://127.0.0.1:*");
-    assert (rc == 0);
-    len = MAX_SOCKET_STRING;
-    rc = zmq_getsockopt (xsub, ZMQ_LAST_ENDPOINT, endpoint2, &len);
+    rc = zmq_bind (xsub, "tcp://127.0.0.1:5561");
     assert (rc == 0);
 
     //  Create a publisher
     void *pub = zmq_socket (ctx, ZMQ_PUB);
     assert (pub);
-    rc = zmq_connect (pub, endpoint2);
+    rc = zmq_connect (pub, "tcp://127.0.0.1:5561");
     assert (rc == 0);
 
     //  Create a subscriber
     void *sub = zmq_socket (ctx, ZMQ_SUB);
     assert (sub);
-    rc = zmq_connect (sub, endpoint1);
+    rc = zmq_connect (sub, "tcp://127.0.0.1:5560");
     assert (rc == 0);
 
     //  Subscribe for all messages.
@@ -70,7 +52,7 @@ int main (void)
     assert (rc == 0);
 
     //  Pass the subscription upstream through the device
-    char buff[32];
+    char buff [32];
     rc = zmq_recv (xpub, buff, sizeof (buff), 0);
     assert (rc >= 0);
     rc = zmq_send (xsub, buff, rc, 0);
@@ -105,5 +87,5 @@ int main (void)
     rc = zmq_ctx_term (ctx);
     assert (rc == 0);
 
-    return 0;
+    return 0 ;
 }
