@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2007-2013 Contributors as noted in the AUTHORS file
+    Copyright (c) 2007-2014 Contributors as noted in the AUTHORS file
 
     This file is part of 0MQ.
 
@@ -21,8 +21,8 @@
 #define __TESTUTIL_HPP_INCLUDED__
 
 #include "../include/zmq.h"
-#include "../include/zmq_utils.h"
-#include "../src/platform.hpp"
+#include "../src/stdint.hpp"
+#include "platform.hpp"
 
 //  This defines the settle time used in tests; raise this if we
 //  get test failures on slower systems due to binds/connects not
@@ -34,6 +34,7 @@
 #include <assert.h>
 #include <stdarg.h>
 #include <string>
+#include <string.h>
 
 #if defined _WIN32
 #   if defined _MSC_VER
@@ -111,15 +112,17 @@ expect_bounce_fail (void *server, void *client)
 {
     const char *content = "12345678ABCDEFGH12345678abcdefgh";
     char buffer [32];
+    int timeout = 150;
 
     //  Send message from client to server
-    int rc = zmq_send (client, content, 32, ZMQ_SNDMORE);
-    assert (rc == 32);
+    int rc = zmq_setsockopt (client, ZMQ_SNDTIMEO, &timeout, sizeof (int));
+    assert (rc == 0);
+    rc = zmq_send (client, content, 32, ZMQ_SNDMORE);
+    assert ((rc == 32) || ((rc == -1) && (errno == EAGAIN)));
     rc = zmq_send (client, content, 32, 0);
-    assert (rc == 32);
+    assert ((rc == 32) || ((rc == -1) && (errno == EAGAIN)));
 
     //  Receive message at server side (should not succeed)
-    int timeout = 150;
     rc = zmq_setsockopt (server, ZMQ_RCVTIMEO, &timeout, sizeof (int));
     assert (rc == 0);
     rc = zmq_recv (server, buffer, 32, 0);
@@ -127,10 +130,13 @@ expect_bounce_fail (void *server, void *client)
     assert (zmq_errno () == EAGAIN);
 
     //  Send message from server to client to test other direction
+    //  If connection failed, send may block, without a timeout
+    rc = zmq_setsockopt (server, ZMQ_SNDTIMEO, &timeout, sizeof (int));
+    assert (rc == 0);
     rc = zmq_send (server, content, 32, ZMQ_SNDMORE);
-    assert (rc == 32);
+    assert (rc == 32 || (rc == -1 && zmq_errno () == EAGAIN));
     rc = zmq_send (server, content, 32, 0);
-    assert (rc == 32);
+    assert (rc == 32 || (rc == -1 && zmq_errno () == EAGAIN));
 
     //  Receive message at client side (should not succeed)
     rc = zmq_setsockopt (client, ZMQ_RCVTIMEO, &timeout, sizeof (int));
@@ -243,7 +249,7 @@ void s_recv_seq (void *socket, ...)
 }
 
 
-// Sets a zero linger period on a socket and closes it.
+//  Sets a zero linger period on a socket and closes it.
 void close_zero_linger (void *socket)
 {
     int linger = 0;
@@ -261,6 +267,14 @@ void setup_test_environment()
     _CrtSetReportMode( _CRT_ASSERT, _CRTDBG_MODE_FILE );
     _CrtSetReportFile( _CRT_ASSERT, _CRTDBG_FILE_STDERR );
 #   endif
+#else
+    // abort test after 60 seconds
+    alarm(60);
+#endif
+#if defined __MVS__
+    // z/OS UNIX System Services: Ignore SIGPIPE during test runs, as a
+    // workaround for no SO_NOGSIGPIPE socket option.
+    signal(SIGPIPE, SIG_IGN);
 #endif
 }
 
